@@ -20,8 +20,8 @@ Serves to construct an association between a project + queue -> pool.
 ::
 
     {
-        'p_q': project_queue :: six.text_type,
-        's': pool_identifier :: six.text_type
+        'p_q': project_queue :: str,
+        's': pool_identifier :: str
     }
 """
 
